#!/usr/bin/env python
# -*- coding: utf-8 -*-

# People Presence Clint -- Client for Predesys People Presence service plugin
# Version: 0.1.0
# Author: Jose Antonio Jimenez Carmona <josantjim@gmail.com>
# License: LGPL 3.0 (see "license" file)

import sys
sys.dont_write_bytecode = True
import time
import xmlrpclib
import gtk
import gobject
import configuration

class WinMain:
    def __init__(self):
        self.config = configuration.load_configuration()
        
        self.gladefile = "winmain.glade"
        self.builder = gtk.Builder()
        self.builder.add_from_file(self.gladefile)
        self.winMain = self.builder.get_object("winMain")
        self.labHeader = self.builder.get_object("labHeader")
        self.trvPeople = self.builder.get_object("trvPeople")
        
        column1 = gtk.TreeViewColumn("Name", gtk.CellRendererText(), text=0)
        column1.set_resizable(False)
        self.trvPeople.append_column(column1)

        self.trvPeopleModel = gtk.ListStore(str)
        self.trvPeople.set_model(self.trvPeopleModel)
        
        self.winMain.set_title(self.config.get_title())
        
        self.builder.connect_signals(self)
        self.winMain.show_all()
        
        self.refresh()
        
    def winmain_destroy(self, widget):
        gtk.main_quit()

    def refresh(self):
        self.trvPeopleModel.clear()
        t = time.localtime()
        formattedTime = "%d/%d/%d - %d:%d" % (t.tm_mday, t.tm_mon, t.tm_year, t.tm_hour, t.tm_min)
            
        try:
            for user in self.get_users():
                self.trvPeopleModel.append([user[0]])        
            self.labHeader.set_text("Current people (%s):" % formattedTime)
        except:
            self.labHeader.set_text("Error calling service (%s):" % formattedTime)
            
        self.timerId = gobject.timeout_add(60000, self.refresh)
        
    def get_users(self):
        users = []
        try:
            client = xmlrpclib.ServerProxy(self.config.get_predesys_webservice_address())
            people = client.run_service("peoplepresence", [])
            for p in people:
                users.append([p[0]])
        except:
            raise
            
        return users
